#!D:\bld\gdal-split_1646904823526\_h_env\python.exe

import sys
# import osgeo_utils.pct2rgb as a convenience to use as a script
from osgeo_utils.pct2rgb import *  # noqa
from osgeo_utils.pct2rgb import main
from osgeo.gdal import deprecation_warn


deprecation_warn('pct2rgb')
sys.exit(main(sys.argv))
